"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initGlobal = void 0;
const chalk_1 = require("chalk");
const fs = require("fs");
const path = require("path");
const find_workspace_root_1 = require("./find-workspace-root");
const output_1 = require("./output");
/**
 * Nx is being run from outside a workspace
 */
function initGlobal() {
    const workspace = find_workspace_root_1.findWorkspaceRoot(process.cwd());
    if (workspace) {
        // Found a workspace root - hand off to the local copy of Nx
        const localNx = path.join(workspace.dir, 'node_modules', '@nrwl', 'cli', 'bin', 'nx.js');
        if (fs.existsSync(localNx)) {
            require(localNx);
        }
        else {
            if (fs.existsSync(path.join(workspace.dir, 'node_modules'))) {
                output_1.output.error({
                    title: `Could not find Nx in this workspace.`,
                    bodyLines: [
                        `To convert an Angular workspace to Nx run: ${chalk_1.default.bold.white(`ng add @nrwl/workspace`)}`,
                    ],
                });
            }
            else {
                output_1.output.error({
                    title: `Could not find a node_modules folder in this workspace.`,
                    bodyLines: [`Have you run ${chalk_1.default.bold.white(`npm/yarn install`)}?`],
                });
            }
            process.exit(1);
        }
    }
    else {
        output_1.output.log({
            title: `The current directory isn't part of an Nx workspace.`,
            bodyLines: [
                `To create a workspace run:`,
                chalk_1.default.bold.white(`npx create-nx-workspace@latest <workspace name>`),
            ],
        });
        output_1.output.note({
            title: `For more information please visit https://nx.dev/`,
        });
        process.exit(1);
    }
}
exports.initGlobal = initGlobal;
//# sourceMappingURL=init-global.js.map